@@ -19,12 +19,23 @@ sub mock_context {
   sub {
     my ($req) = @_;
     my $c;
-    test_psgi app => sub {
-      my $env = shift;
-      $c = $class->prepare( env => $env, response_cb => sub { } );
-      return [ 200, [ 'Content-type' => 'text/plain' ], ['Created mock OK'] ];
-      },
-      client => sub {
+    my $app = sub {
+        my $env = shift;
+
+        # legacy implementation handles stash creation via MyApp->prepare
+
+        $c = $class->prepare( env => $env, response_cb => sub { } );
+        return [ 200, [ 'Content-type' => 'text/plain' ], ['Created mock OK'] ];
+    };
+
+    # handle stash-as-middleware implementation from v5.90070
+    if (eval { $Catalyst::VERSION } >= 5.90070) {
+        Class::Load::load_class('Catalyst::Middleware::Stash');
+        $app = Catalyst::Middleware::Stash->wrap($app);
+    }
+
+    test_psgi app => $app,
+    client => sub {
       my $cb = shift;
       $cb->($req);
     };
@@ -35,15 +46,18 @@ sub mock_context {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 CatalystX::Test::MockContext - Conveniently create $c objects for testing
 
 =head1 VERSION
 
-version 0.000001
+version 0.000002
 
 =head1 SYNOPSIS
 
@@ -66,10 +80,9 @@ Eden Cardim <edencardim@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Eden Cardim.
+This software is copyright (c) 2017 by Eden Cardim.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
